//
//  FullTextFilterController.m
//  FlexGrid101
//
//  Copyright (c) 2015 GrapeCity. All rights reserved.
//

#import "FullTextFilterController.h"
#import "CustomerData.h"
#import "XuniFlexGridKit/XuniFlexGridKit.h"


@interface FullTextFilterController (){
    UITextField *filterField;
    NSTimer *timer;
}

@end

@implementation FullTextFilterController

- (void)viewDidLoad {
    [super viewDidLoad];
    // Do any additional setup after loading the view, typically from a nib.
    filterField = [[UITextField alloc] init];
    filterField.delegate = self;
    filterField.text = NSLocalizedString(@"Enter text to Filter", nil);
    filterField.returnKeyType = UIReturnKeyDone;
    filterField.keyboardType = UIKeyboardTypeDefault;
    filterField.backgroundColor = [UIColor lightGrayColor];
    filterField.borderStyle = UITextBorderStyleRoundedRect;
    filterField.clearButtonMode = UITextFieldViewModeWhileEditing;
    FlexGrid *flex = [[FlexGrid alloc] init];
    flex.isReadOnly = true;
    flex.itemsSource = [CustomerData getCustomerData:100000];
    flex.tag = 1;
    filterField.tag = 2;
    [self.view addSubview:flex];
    [self.view addSubview:filterField];
}

- (void)didReceiveMemoryWarning {
    [super didReceiveMemoryWarning];
    // Dispose of any resources that can be recreated.
}


- (void)viewDidLayoutSubviews{
    [super viewDidLayoutSubviews];
    FlexGrid *flex = (FlexGrid*)[self.view viewWithTag:1];
    //filterField = (UITextField*)[self.view viewWithTag:2];
    
    filterField.frame = CGRectMake(0, 65, self.view.bounds.size.width, 50);
    flex.frame = CGRectMake(0, 115, self.view.bounds.size.width, self.view.bounds.size.height-115);
    [flex setNeedsDisplay];
}

-(BOOL)textFieldShouldBeginEditing:(UITextField *)textField{
    //[textField selectAll:nil];
    return true;
}
-(void)textFieldDidBeginEditing:(UITextField *)textField{
    [textField selectAll:nil];
}
-(bool)textField:(UITextField *)textField shouldChangeCharactersInRange:(NSRange)range replacementString:(NSString *)string{
    if(timer != nil){
        [timer invalidate];
    }
    timer = [NSTimer scheduledTimerWithTimeInterval:2 target:self selector:@selector(filter) userInfo:nil repeats:false];
    [[NSRunLoop mainRunLoop] addTimer:timer forMode:NSRunLoopCommonModes];
    
    return true;
}

-(void)filter{
    dispatch_queue_t myQueue = dispatch_queue_create("myQueue", nil);
    dispatch_async(myQueue, ^{
        //filtering code... see sample for full implementation
        FlexGrid *flex =  (FlexGrid *)[self.view viewWithTag:1];
        NSDateFormatter *dateFormat = [[NSDateFormatter alloc] init];
        [dateFormat setDateFormat:@"M/d/yy"];
        
        if(filterField.text.length)
        {
            flex.collectionView.filter = ^ BOOL (NSObject *item){
                CustomerData *d = (CustomerData*)item;
                
                if ([[NSString stringWithFormat:@"%lu", d.customerID] rangeOfString:filterField.text].location != NSNotFound) {
                    return true;
                }
                else if ([[NSString stringWithFormat:@"%lu", d.countryID] rangeOfString:filterField.text].location != NSNotFound) {
                    return true;
                }
                else if ([[NSString stringWithFormat:@"%@", d.email] rangeOfString:filterField.text].location != NSNotFound) {
                    return true;
                }
                else if ([d.firstName rangeOfString:filterField.text].location != NSNotFound) {
                    return true;
                }
                else if ([d.lastName rangeOfString:filterField.text].location != NSNotFound)
                {
                    return true;
                }
                else if ([d.country rangeOfString:filterField.text].location != NSNotFound){
                    return true;
                }
                else if ([d.city rangeOfString:filterField.text].location != NSNotFound){
                    return true;
                }
                else if ([d.address rangeOfString:filterField.text].location != NSNotFound){
                    return true;
                }
                else if ([[dateFormat stringFromDate:d.lastOrderDate] rangeOfString:filterField.text].location != NSNotFound) {
                    return true;
                }
                else {
                    return false;
                }
            };
        }
        else
        {
            flex.collectionView.filter = nil;
        }
        dispatch_async(dispatch_get_main_queue(), ^{[flex setNeedsDisplay];});
    });
}
-(BOOL)textFieldShouldEndEditing:(UITextField *)textField{
    return true;
}

-(BOOL)textFieldShouldReturn:(UITextField *)textField{
    [textField resignFirstResponder];
    return true;
}

@end
